@@ -1,3 +1,6 @@
+from collections.abc import Sequence
+from typing import Optional
+
 from sybil.evaluators.python import pad, PythonEvaluator
 from sybil.parsers.abstract import AbstractCodeBlockParser
 from sybil.parsers.rest.lexers import DirectiveLexer, DirectiveInCommentLexer
@@ -16,10 +19,10 @@ class CodeBlockParser(AbstractCodeBlockParser):
         You can also override the :meth:`evaluate` method below.
     """
 
-    def __init__(self, language: str = None, evaluator: Evaluator = None):
+    def __init__(self, language: Optional[str] = None, evaluator: Optional[Evaluator] = None) -> None:
         super().__init__(
             [
-                DirectiveLexer(directive=r'code-block'),
+                DirectiveLexer(directive=r'(sourcecode|code-block|code)'),
                 DirectiveInCommentLexer(directive=r'(invisible-)?code(-block)?'),
             ],
             language, evaluator
@@ -33,10 +36,10 @@ class PythonCodeBlockParser(CodeBlockParser):
     A :any:`Parser` for Python :ref:`codeblock-parser` examples.
 
     :param future_imports:
-        An optional list of strings that will be turned into
+        An optional sequence of strings that will be turned into
         ``from __future__ import ...`` statements and prepended to the code
         in each of the examples found by this parser.
     """
 
-    def __init__(self, future_imports=()):
+    def __init__(self, future_imports: Sequence[str] = ()) -> None:
         super().__init__(language='python', evaluator=PythonEvaluator(future_imports))
